$Title Sets Definition
$ontext
--------------------------------------------------------------------------------
------------------------------ General Header ----------------------------------
--------------------------------------------------------------------------------
         Hybrid Top-down Computable General Equilibrium and Bottom-up Electricity Expansion Model
         Renato Rodrigues
         Instituto de Investigacin Tecnolgica
         Date: 26, may, 2011
--------------------------------------------------------------------------------
--------------------------- End of General Header ------------------------------
--------------------------------------------------------------------------------
$offtext

*-------------------------------------------------------------------------------
*------------------------------- Defining Options ------------------------------
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*------------------------------ Solver definition ------------------------------
*-------------------------------------------------------------------------------
option LP=CPLEX;
option NLP=CONOPT;
option MCP=PATH;

*-------------------------------------------------------------------------------
*------------------------ Choose the years to be simulated ---------------------
*-------------------------------------------------------------------------------
*Defining years of execution
sets
	y        years           / 1900*2100 /
    ey(y)        execution year  (for CGE model)                                         /2005/
    eys(y)       execution years (for electricity model)                                 /2005*2005/;

*-------------------------------------------------------------------------------
*---------- Choose the costs to be considered in the electricity model ---------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF
Scalars
       exec_fc           Fuel costs                                                      /1/
       exec_co2          CO2 emission costs                                              /1/
*preciso revisar desagregacao porque no esto saindo valores aceitaveis quando considero co2

       exec_vom          Operation and maintenance variable equipaments reposition costs /1/
       exec_oem_equip    Operation and maintenance equipments fixed costs                /1/
       exec_oem_labor    Operation and maintenance labor fixed costs                     /1/
       exec_oem_sc       Operation and maintenance social contribution fixed costs       /1/
       exec_capac        Installed capacity amortization costs paid in the year          /1/
       exec_emiss_rights Technology emission rights distributed by the government        /1/
       exec_renew_prem   Renewable premium income                                        /0/;


*-------------------------------------------------------------------------------
*------------------------ Choose the location to be considered in the models ---------------------
*-------------------------------------------------------------------------------
*Defining locations of execution (I am having problems with extra peninsular location due to the high level of non-paid capacity; therefore its execution should be maintained null for the time being)
Set      l               Peninsular only electricity market                              /Peninsular/;
*set      l               Peninsular and Extra Peninsular electricity markets             /Peninsular, Extra Peninsular/;

alias (l,l_alias);

*-------------------------------------------------------------------------------
*---------------------- Choose the DR policy to be evaluated -------------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF
Scalars
*Active Demand Management policy
       exec_DR_displac Demand reponse with load displacements                            /0/
       exec_DR_reduc   Demand reponse with load conservation savings                     /0/;

*-------------------------------------------------------------------------------
*------- Choose the objective fucnction of the SAM disaggregation scheme -------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF  (choose only one of the bellow alternatives)
Scalars
       exec_MinMax       MinMax deviation                                                /0/
       exec_MinMax_plus_lineal_term MinMax with additional term to exclude unnecessary deviations /1/
       exec_Quadratic   Min the squared deviation                                        /0/;

*-------------------------------------------------------------------------------
*----------------- Choose the Top-Down model type - MCP or NLP -----------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF (choose only one of the bellow alternatives)
Scalars
       exec_MCP          Top-Down model soved as a mixed complementarity problem         /1/
       exec_NLP          Top-Down model solved as a non lineal problem                   /0/;


*-------------------------------------------------------------------------------
*------------------- Choose the Bottom-Up model type - MCP or LP ----------------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF (choose only one of the bellow alternatives)
Scalars
       exec_BU_MCP       Bottom-Up model soved as a mixed complementarity problem        /0/
       exec_BU_LP        Bottom-Up model solved as a lineal problem                      /1/;


*-------------------------------------------------------------------------------
*-------------------------- Load segments aggregation --------------------------
*-------------------------------------------------------------------------------
sets
month / january,february,march,april,may,june,july,august,september,october,november,december /
day / 1*31 /
hour / 1*25 /
daytype / Working,Holiday /
weekday / Monday,Tuesday,Wednesday,Thursday,Friday,Saturday,Sunday /
p period load segment / all_months_all_days /
load_segment_definition(p,month,daytype,weekday) / all_months_all_days.january.Holiday.Friday,all_months_all_days.january.Holiday.Monday,all_months_all_days.january.Holiday.Saturday,all_months_all_days.january.Holiday.Sunday,all_months_all_days.january.Holiday.Thursday,all_months_all_days.january.Holiday.Tuesday,all_months_all_days.january.Holiday.Wednesday,all_months_all_days.january.Working.Friday,all_months_all_days.january.Working.Monday,all_months_all_days.january.Working.Thursday,all_months_all_days.january.Working.Tuesday,all_months_all_days.january.Working.Wednesday,all_months_all_days.february.Holiday.Friday,all_months_all_days.february.Holiday.Monday,all_months_all_days.february.Holiday.Saturday,all_months_all_days.february.Holiday.Sunday,all_months_all_days.february.Holiday.Thursday,all_months_all_days.february.Holiday.Tuesday,all_months_all_days.february.Holiday.Wednesday,all_months_all_days.february.Working.Friday,all_months_all_days.february.Working.Monday,all_months_all_days.february.Working.Thursday,all_months_all_days.february.Working.Tuesday,all_months_all_days.february.Working.Wednesday,all_months_all_days.march.Holiday.Friday,all_months_all_days.march.Holiday.Monday,all_months_all_days.march.Holiday.Saturday,all_months_all_days.march.Holiday.Sunday,all_months_all_days.march.Holiday.Thursday,all_months_all_days.march.Holiday.Tuesday,all_months_all_days.march.Holiday.Wednesday,all_months_all_days.march.Working.Friday,all_months_all_days.march.Working.Monday,all_months_all_days.march.Working.Thursday,all_months_all_days.march.Working.Tuesday,all_months_all_days.march.Working.Wednesday,all_months_all_days.april.Holiday.Friday,all_months_all_days.april.Holiday.Monday,all_months_all_days.april.Holiday.Saturday,all_months_all_days.april.Holiday.Sunday,all_months_all_days.april.Holiday.Thursday,all_months_all_days.april.Holiday.Tuesday,all_months_all_days.april.Holiday.Wednesday,all_months_all_days.april.Working.Friday,all_months_all_days.april.Working.Monday,all_months_all_days.april.Working.Thursday,all_months_all_days.april.Working.Tuesday,all_months_all_days.april.Working.Wednesday,all_months_all_days.may.Holiday.Friday,all_months_all_days.may.Holiday.Monday,all_months_all_days.may.Holiday.Saturday,all_months_all_days.may.Holiday.Sunday,all_months_all_days.may.Holiday.Thursday,all_months_all_days.may.Holiday.Tuesday,all_months_all_days.may.Holiday.Wednesday,all_months_all_days.may.Working.Friday,all_months_all_days.may.Working.Monday,all_months_all_days.may.Working.Thursday,all_months_all_days.may.Working.Tuesday,all_months_all_days.may.Working.Wednesday,all_months_all_days.june.Holiday.Friday,all_months_all_days.june.Holiday.Monday,all_months_all_days.june.Holiday.Saturday,all_months_all_days.june.Holiday.Sunday,all_months_all_days.june.Holiday.Thursday,all_months_all_days.june.Holiday.Tuesday,all_months_all_days.june.Holiday.Wednesday,all_months_all_days.june.Working.Friday,all_months_all_days.june.Working.Monday,all_months_all_days.june.Working.Thursday,all_months_all_days.june.Working.Tuesday,all_months_all_days.june.Working.Wednesday,all_months_all_days.july.Holiday.Friday,all_months_all_days.july.Holiday.Monday,all_months_all_days.july.Holiday.Saturday,all_months_all_days.july.Holiday.Sunday,all_months_all_days.july.Holiday.Thursday,all_months_all_days.july.Holiday.Tuesday,all_months_all_days.july.Holiday.Wednesday,all_months_all_days.july.Working.Friday,all_months_all_days.july.Working.Monday,all_months_all_days.july.Working.Thursday,all_months_all_days.july.Working.Tuesday,all_months_all_days.july.Working.Wednesday,all_months_all_days.august.Holiday.Friday,all_months_all_days.august.Holiday.Monday,all_months_all_days.august.Holiday.Saturday,all_months_all_days.august.Holiday.Sunday,all_months_all_days.august.Holiday.Thursday,all_months_all_days.august.Holiday.Tuesday,all_months_all_days.august.Holiday.Wednesday,all_months_all_days.august.Working.Friday,all_months_all_days.august.Working.Monday,all_months_all_days.august.Working.Thursday,all_months_all_days.august.Working.Tuesday,all_months_all_days.august.Working.Wednesday,all_months_all_days.september.Holiday.Friday,all_months_all_days.september.Holiday.Monday,all_months_all_days.september.Holiday.Saturday,all_months_all_days.september.Holiday.Sunday,all_months_all_days.september.Holiday.Thursday,all_months_all_days.september.Holiday.Tuesday,all_months_all_days.september.Holiday.Wednesday,all_months_all_days.september.Working.Friday,all_months_all_days.september.Working.Monday,all_months_all_days.september.Working.Thursday,all_months_all_days.september.Working.Tuesday,all_months_all_days.september.Working.Wednesday,all_months_all_days.october.Holiday.Friday,all_months_all_days.october.Holiday.Monday,all_months_all_days.october.Holiday.Saturday,all_months_all_days.october.Holiday.Sunday,all_months_all_days.october.Holiday.Thursday,all_months_all_days.october.Holiday.Tuesday,all_months_all_days.october.Holiday.Wednesday,all_months_all_days.october.Working.Friday,all_months_all_days.october.Working.Monday,all_months_all_days.october.Working.Thursday,all_months_all_days.october.Working.Tuesday,all_months_all_days.october.Working.Wednesday,all_months_all_days.november.Holiday.Friday,all_months_all_days.november.Holiday.Monday,all_months_all_days.november.Holiday.Saturday,all_months_all_days.november.Holiday.Sunday,all_months_all_days.november.Holiday.Thursday,all_months_all_days.november.Holiday.Tuesday,all_months_all_days.november.Holiday.Wednesday,all_months_all_days.november.Working.Friday,all_months_all_days.november.Working.Monday,all_months_all_days.november.Working.Thursday,all_months_all_days.november.Working.Tuesday,all_months_all_days.november.Working.Wednesday,all_months_all_days.december.Holiday.Friday,all_months_all_days.december.Holiday.Monday,all_months_all_days.december.Holiday.Saturday,all_months_all_days.december.Holiday.Sunday,all_months_all_days.december.Holiday.Thursday,all_months_all_days.december.Holiday.Tuesday,all_months_all_days.december.Holiday.Wednesday,all_months_all_days.december.Working.Friday,all_months_all_days.december.Working.Monday,all_months_all_days.december.Working.Thursday,all_months_all_days.december.Working.Tuesday,all_months_all_days.december.Working.Wednesday /;

Scalar
       UseLoadBlockAggregation                                                           /1/;
Set b load blocks /all_hours/;

Parameters
Block_min_percentil(b) /all_hours 0/
Block_max_percentil(b) /all_hours 100/;

***********************************************************************************************************************************************************
