$Title Sets Definition
$ontext
--------------------------------------------------------------------------------
------------------------------ General Header ----------------------------------
--------------------------------------------------------------------------------
         Top-down Pure CGE Model
         Renato Rodrigues
         Instituto de Investigacin Tecnolgica
         Date: 26, may, 2011
--------------------------------------------------------------------------------
--------------------------- End of General Header ------------------------------
--------------------------------------------------------------------------------
$offtext

*-------------------------------------------------------------------------------
*------------------------------------- Sets ------------------------------------
*-------------------------------------------------------------------------------
*Sets defined in sets.gms

*-------------------------------------------------------------------------------
*---------------------------------- Parameters ---------------------------------
*-------------------------------------------------------------------------------
*Exogenously defined parameters in exogenous_parameters.gms
*elasticity_va(s)      Elasticity of substitution between productive factors of sector s
*elasticity_d(g)       Elasticity of substitution between imported and domestic produced good g
*elasticity_q(g)       Elasticity of transformation between domestic and external destined supply
*p_m_initial(y,g)      International price of the imported good g
*p_ex_initial(y,g)     International price of exported good g
*mu_cpi(y,g)

*remaining parameters exclusive to this model
Parameters
q_i_pf(y,i,pf)        Quantity of production factor pf owned by institution i (households or government)
c_h(y,g)              Representative household marginal propensity to consume domestic good g
s_propensity_h(y)     Representative Household marginal propensity to save
psc_h(y)              Proportion of annual social contribution payments reverted directly to households
alpha_va(y,s)         Productivity parameter of sector value added composite good production function
a_va_pf(y,pf,s)       Share parameter of product factor on value added composite good production function
c_ii_share(y,g,s)     Share parameter of intermediate composites inputs g on sector s production function
c_va_share(y,s)       Share parameter of value added composite input on sector s production function
alpha_d(y,g)          Productivity parameter of Armington aggregated imported and domestic produced supply of good g
a_d_q(y,g)            Share parameter of domestic produced supply on Armington aggregate
a_d_m(y,g)            Share parameter of imports supply on Armington aggregate
beta_q(y,g)           Productivity parameter of CET export and domestically destined good g
b_q_q(y,g)            Share parameter of CET domestically destined good g
b_q_ex(y,g)           Share parameter of CET exportation destined good g
q_gov_initial(y,g)    Government initial demand for good g
transf_g_h(y)         Net transfers from the government to the households
transf_ext_g(y)       Net transfers from the exterior to the government
transf_ext_h(y)       Net transfers from the exterior to the households
transf_ext_k(y)       Net capital transfers from the exterior
Theta(y,g)            Share parameter of demand for investment good g
;


*Initial Variable Values
Parameters
initial_Q_H_D_CGE(y,g), initial_P_PF_CGE(y,pf), initial_Y_H_CGE(y), initial_Q_PF_CGE(y,pf,s),
initial_Q_VA_CGE(y,s), initial_P_VA_CGE(y,s), initial_Q_II_CGE(y,g,s), initial_Q_S_CGE(y,s),
initial_P_S_CGE(y,g), initial_Q_M_CGE(y,g), initial_Q_D_CGE(y,g), initial_P_D_CGE(y,g),
initial_Q_EX_CGE(y,g), initial_Q_Q_CGE(y,g), initial_P_Q_CGE(y,g), initial_Y_G_CGE(y),
initial_E_G_CGE(y), initial_Y_TAX_CGE(y), initial_S_TOTAL_CGE(y), initial_S_TOTAL_H_CGE(y),
initial_S_TOTAL_G_CGE(y), initial_S_TOTAL_EXT_CGE(y), initial_I_TOTAL_CGE(y), initial_Q_I_D_CGE(y,g),
initial_CPI(y);

initial_P_PF_CGE(ey,pf)=p_pf_initial(ey,pf);
initial_P_VA_CGE(ey,s)=p_va_initial(ey,s);
initial_P_S_CGE(ey,g)=p_s_initial(ey,g);
initial_P_D_CGE(ey,g)=p_d_initial(ey,g);
initial_P_Q_CGE(ey,g)=p_q_initial(ey,g);
initial_Q_H_D_CGE(ey,g)=e_g_i(ey,g,"Households")/initial_P_Q_CGE(ey,g);
initial_Y_H_CGE(ey)=sum(pf,e_i_pf(ey,"Households",pf))+sum(tx,e_i_tx(ey,"Households",tx))+(e_transf_i(ey,"Households","Government")-e_transf_i(ey,"Government","Households"))+(e_transf_k_ext_i(ey,"Households")-e_transf_k_i_ext(ey,"Households"));
initial_Q_PF_CGE(ey,pf,s)=e_pf_s(ey,pf,s)/p_pf_initial(ey,pf);
initial_Q_VA_CGE(ey,s)= ( sum(pf, initial_Q_PF_CGE(ey,pf,s)*initial_P_PF_CGE(ey,pf)) + e_tx_sam(ey,"Social_Contributions",s) ) / initial_P_VA_CGE(ey,s);
initial_Q_II_CGE(ey,g,s)= e_ii_s(ey,g,s) / initial_P_Q_CGE(ey,g);
initial_Q_S_CGE(ey,s)= ( initial_Q_VA_CGE(ey,s)*initial_P_VA_CGE(ey,s) + sum(g, initial_Q_II_CGE(ey,g,s)*initial_P_Q_CGE(ey,g)) + e_tx_sam(ey,"Product_Tax",s) - sum(i,e_transf_i_s(ey,i,s)) + e_tx_sam(ey,"Production_Taxes",s) ) / initial_P_S_CGE(ey,s);
initial_Q_M_CGE(ey,g)= e_m_s(ey,g) / p_m_initial(ey,g);
initial_Q_D_CGE(ey,g)= ( initial_Q_S_CGE(ey,g)*initial_P_S_CGE(ey,g) + initial_Q_M_CGE(ey,g)*p_m_initial(ey,g) + e_tx_sam(ey,"CO2_Payments",g) ) / initial_P_D_CGE(ey,g);
initial_Q_EX_CGE(ey,g)= e_g_ex(ey,g) / p_ex_initial(ey,g);
initial_Q_Q_CGE(ey,g)= ( initial_Q_D_CGE(ey,g)*initial_P_D_CGE(ey,g) - initial_Q_EX_CGE(ey,g)*p_ex_initial(ey,g)) / initial_P_Q_CGE(ey,g);
initial_Y_G_CGE(ey)=sum(pf,e_i_pf(ey,"Government",pf))+e_transf_k_ext_i(ey,"Government")-e_transf_k_i_ext(ey,"Government")+sum((tx,i),e_i_tx(ey,i,tx));
initial_E_G_CGE(ey)=sum(g,e_g_i(ey,g,"Government"))+sum(tx,e_tx_sam(ey,tx,"Government"))+e_i_tx(ey,"Households","Social_Contributions")+e_transf_i(ey,"Households","Government")-e_transf_i(ey,"Government","Households")+sum(s,e_transf_i_s(ey,"Government",s));
initial_Y_TAX_CGE(ey)=sum((tx,sam),e_tx_sam(ey,tx,sam));
initial_S_TOTAL_H_CGE(ey)=e_i_sav(ey,"Households");
initial_S_TOTAL_G_CGE(ey)=e_i_sav(ey,"Government");
initial_S_TOTAL_EXT_CGE(ey)=e_sav(ey);
initial_S_TOTAL_CGE(ey)=initial_S_TOTAL_H_CGE(ey)+initial_S_TOTAL_G_CGE(ey)+initial_S_TOTAL_EXT_CGE(ey)+e_transf_k_ext_spain(ey);
initial_Q_I_D_CGE(ey,g)=e_inv(ey,g) / initial_P_Q_CGE(ey,g);
initial_I_TOTAL_CGE(ey)=sum(g,initial_Q_I_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)) + e_tx_sam(ey,"Product_Tax","Saves-Investments");
initial_CPI(ey)=sum(g, initial_P_Q_CGE(ey,g)*mu_cpi(ey,g));

q_i_pf(ey,i,pf)=e_i_pf(ey,i,pf)/initial_P_PF_CGE(ey,pf);
q_gov_initial(ey,g)=e_g_i(ey,g,"Government")/initial_P_Q_CGE(ey,g);
transf_g_h(ey)=e_transf_i(ey,"Households","Government")-e_transf_i(ey,"Government","Households");
transf_ext_g(ey)=e_transf_k_ext_i(ey,"Government")-e_transf_k_i_ext(ey,"Government");
transf_ext_h(ey)=e_transf_k_ext_i(ey,"Households")-e_transf_k_i_ext(ey,"Households");
transf_ext_k(ey)=e_transf_k_ext_spain(ey);

*---------scaling parameters---------------
parameter        scale_factor    /1/;
scale_factor=1e4;
CGE_scale_parameters(/)
*---------end of scaling parameters---------------

*Initial production function values
c_h(ey,g)=initial_Q_H_D_CGE(ey,g)*(1+tx_rate(ey,"Households","Product_Tax"))*initial_P_Q_CGE(ey,g) / (initial_Y_H_CGE(ey)-initial_S_TOTAL_H_CGE(ey));
s_propensity_h(ey)=initial_S_TOTAL_H_CGE(ey)/initial_Y_H_CGE(ey);
psc_h(ey)=e_i_tx(ey,"Households","Social_Contributions")/sum(i,e_i_tx(ey,i,"Social_Contributions"));
a_va_pf(ey,"Labor",s)= ( (1+tx_rate_sc(ey,"Labor",s))*initial_P_PF_CGE(ey,"Labor")*initial_Q_PF_CGE(ey,"Labor",s)**(1/elasticity_VA(s)) ) / sum(pf,( (1+tx_rate_sc(ey,pf,s))*initial_P_PF_CGE(ey,pf)*initial_Q_PF_CGE(ey,pf,s)**(1/elasticity_VA(s))));
a_va_pf(ey,"Capital",s)=1-a_va_pf(ey,"Labor",s);
alpha_va(ey,s)=initial_Q_VA_CGE(ey,s)*[ ( sum(pf, a_va_pf(ey,pf,s)*(initial_Q_PF_CGE(ey,pf,s)**((elasticity_va(s)-1)/elasticity_va(s)))) )** ( elasticity_va(s)/(1-elasticity_va(s)) ) ];
c_ii_share(ey,g,s)=initial_Q_II_CGE(ey,g,s)/initial_Q_S_CGE(ey,s);
c_va_share(ey,s)=initial_Q_VA_CGE(ey,s)/initial_Q_S_CGE(ey,s);
a_d_q(ey,g)= ( (initial_P_S_CGE(ey,g)* initial_Q_S_CGE(ey,g)**(1/elasticity_D(g))) ) / ( ((initial_P_S_CGE(ey,g)* initial_Q_S_CGE(ey,g)**(1/elasticity_D(g))))+((p_m_initial(ey,g)* initial_Q_M_CGE(ey,g)**(1/elasticity_D(g)))) );
a_d_m(ey,g)=1-a_d_q(ey,g);
alpha_d(ey,g)= initial_Q_D_CGE(ey,g)* { { (a_d_q(ey,g)*(initial_Q_S_CGE(ey,g)**[(elasticity_D(g)-1)/elasticity_D(g)])) + (a_d_m(ey,g)*(initial_Q_M_CGE(ey,g)**[(elasticity_D(g)-1)/elasticity_D(g)])) }**[elasticity_D(g)/(1-elasticity_D(g))] };
b_q_q(ey,g)=( initial_Q_EX_CGE(ey,g)**(1/elasticity_q(g))*initial_P_Q_CGE(ey,g) ) / ( ( initial_Q_EX_CGE(ey,g)**(1/elasticity_q(g))*initial_P_Q_CGE(ey,g) ) +  ( initial_Q_Q_CGE(ey,g)**(1/elasticity_q(g))*(1+tx_rate(ey,"Exports","Product_Tax"))*p_ex_initial(ey,g) ) );
b_q_ex(ey,g)=1-b_q_q(ey,g);
beta_q(ey,g)=initial_Q_D_CGE(ey,g)*{ { (b_q_q(ey,g)*(initial_Q_Q_CGE(ey,g)**[(elasticity_q(g)+1)/elasticity_q(g)])) + (b_q_ex(ey,g)*(initial_Q_EX_CGE(ey,g)**[(elasticity_q(g)+1)/elasticity_q(g)])) }**[(-elasticity_q(g))/(elasticity_q(g)+1)] };
Theta(ey,g)=(initial_Q_I_D_CGE(ey,g)*(1+tx_rate(ey,"Saves-Investments","Product_Tax"))*initial_P_Q_CGE(ey,g))/initial_I_TOTAL_CGE(ey);

*---------Scalling CES Parameters---------------
*Scalling CES Parameters to avoid exagerated dimension calculations
parameters
         scaleparameter_a_VA(ey,s)
         scaleparameter_a_D(ey,g)
         scaleparameter_b_EX(ey,g);

         scaleparameter_a_VA(ey,s)=1;
         scaleparameter_a_D(ey,g)=1;
         scaleparameter_b_EX(ey,g)=1;

         scaleparameter_a_VA(ey,s)$((a_va_pf(ey,"Labor",s)*a_va_pf(ey,"Capital",s)) lt 1e-3) = min(a_va_pf(ey,"Labor",s),a_va_pf(ey,"Capital",s))*1e3;
         a_va_pf(ey,"Labor",s)=a_va_pf(ey,"Labor",s)/scaleparameter_a_VA(ey,s);
         a_va_pf(ey,"Capital",s)=a_va_pf(ey,"Capital",s)/scaleparameter_a_VA(ey,s);
         alpha_va(ey,s)=alpha_va(ey,s)*scaleparameter_a_VA(ey,s)**[elasticity_va(s)/(elasticity_va(s)-1)];

         scaleparameter_a_D(ey,g)$((a_d_q(ey,g)*a_d_m(ey,g)) lt 1e-3) = min(a_d_q(ey,g),a_d_m(ey,g))*1e3;
         a_d_q(ey,g)=a_d_q(ey,g)/scaleparameter_a_D(ey,g);
         a_d_m(ey,g)=a_d_m(ey,g)/scaleparameter_a_D(ey,g);
         alpha_d(ey,g)=alpha_d(ey,g)*scaleparameter_a_D(ey,g)**[elasticity_d(g)/(elasticity_d(g)-1)];

         scaleparameter_b_EX(ey,g) $((b_q_q(ey,g)*b_q_ex(ey,g)) lt 1e-3) = min(b_q_q(ey,g),b_q_ex(ey,g))*1e3;
         b_q_q(ey,g)=b_q_q(ey,g)/scaleparameter_b_EX(ey,g);
         b_q_ex(ey,g)=b_q_ex(ey,g)/scaleparameter_b_EX(ey,g);
         beta_q(ey,g)=beta_q(ey,g)*scaleparameter_b_EX(ey,g)**[elasticity_q(g)/(elasticity_q(g)+1)];
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*------------------------------------- Variables -------------------------------
*-------------------------------------------------------------------------------
Variables
Q_H_D_CGE(y,g)           Household domestic goods demand
P_PF_LABOR_CGE(y)        Price of production factor labor
P_PF_CAPITAL_CGE(y)      Price of production factor capital
Y_H_CGE(y)               Total household income
Q_PF_LABOR_CGE(y,s)      Quantity of production factor labor
Q_PF_CAPITAL_CGE(y,s)    Quantity of production factor capital
Q_VA_CGE(y,s)            Quantity of value added composite good produced by sector s
P_VA_CGE(y,s)            Price of value added composite good of a specific sector s
Q_II_CGE(y,g,s)          Quantity of intermediary input g utilized by a specific sector s
Q_S_CGE(y,s)             Quantity of the commodity produced by a specific sector s
P_S_CGE(y,g)             Price of commodity produced by a specific sector s (without foreign aggregations and production taxes)
Q_M_CGE(y,g)             Quantity of good g imported from the exterior
Q_D_CGE(y,g)             Quantity of aggregated imported and domestic produced supply of good g
P_D_CGE(y,g)             Price of Armington aggregated price of the good g
Q_EX_CGE(y,g)            Quantity of goods g exported to the exterior
Q_Q_CGE(y,g)             Quantity of final domestic market supply of good g
P_Q_CGE(y,g)             Price of final domestic good g
Y_G_CGE(y)               Total government income
E_G_CGE(y)               Total government expenditure
Y_TAX_CGE(y)             Total government taxes income
S_TOTAL_CGE(y)           Total economy savings
S_TOTAL_H_CGE(y)         Households savings
S_TOTAL_G_CGE(y)         Government savings
S_TOTAL_EXT_CGE(y)       Foreign total savings
I_TOTAL_CGE(y)           Total investment
Q_I_D_CGE(y,g)           Quantity of good g demanded as investment good
CPI_CGE(ey)              Numeraire
DUMMY_CGE                Dummy variable used on NLP solution
WALRAS_CGE(y)            Walras check variable applied to savings investments equality
Y_ENV_TAX(ey,pollut)
SC_ENV_SUBSIDY_RATE(ey)
LUMP_SUM_ENV_SUBSIDY(ey)
RENEWABLE_PREMIUM_TAX_RATE(ey,s)
;

Positive Variables
Q_H_D_CGE, P_PF_LABOR_CGE, P_PF_CAPITAL_CGE, Y_H_CGE, Q_PF_LABOR_CGE,
Q_PF_CAPITAL_CGE, Q_VA_CGE, P_VA_CGE, Q_II_CGE, Q_S_CGE, P_S_CGE, Q_M_CGE,
Q_D_CGE, P_D_CGE, Q_EX_CGE, Q_Q_CGE, P_Q_CGE, Y_G_CGE, E_G_CGE, Y_TAX_CGE,
S_TOTAL_CGE, S_TOTAL_H_CGE, S_TOTAL_G_CGE, S_TOTAL_EXT_CGE, I_TOTAL_CGE, Q_I_D_CGE
Y_ENV_TAX, SC_ENV_SUBSIDY_RATE, LUMP_SUM_ENV_SUBSIDY, RENEWABLE_PREMIUM_TAX_RATE
;

*-------------------------------------------------------------------------------
*----------------------------- Defining Model Equations ------------------------
*-------------------------------------------------------------------------------
Equations
eq_2_3_8(ey,g)
eq_3_7_1(ey)
eq_3_7_2(ey)
eq_2_4_8(ey,s)
eq_2_4_9(ey,s)
eq_2_4_10(ey,s)
eq_2_4_15(ey,g,s)
eq_2_4_16(ey,s)
eq_2_4_17(ey,s)
eq_3_3_8(ey,g)
eq_3_3_9(ey,g)
eq_3_3_10(ey,g)
eq_3_3_17(ey,g)
eq_3_3_18(ey,g)
eq_3_3_19(ey,g)
eq_3_4_1(ey)
eq_3_4_2(ey)
eq_3_4_3(ey)
eq_3_4_4(ey)
eq_3_5_1(ey)
eq_3_5_2(ey)
eq_3_5_3(ey,g)
eq_3_6_1_a(ey)
eq_3_6_1_b(ey)
eq_3_6_2(ey,g)
eq_3_6_3(ey)
eq_CPI(ey)
eq_object_function_CGE

eq_extra_1(ey,pollut)
eq_extra_2(ey)
eq_extra_3(ey)
eq_extra_4(ey,s)
;


eq_2_3_8(ey,g)..
Q_H_D_CGE(ey,g) =e= ( c_h(ey,g)*(1-s_propensity_h(ey))*Y_H_CGE(ey) ) / ( (1+tx_rate(ey,"Households","Product_Tax"))*P_Q_CGE(ey,g) ) ;

eq_3_7_1(ey)..
Y_H_CGE(ey)=e=q_i_pf(ey,"Households","Labor")*P_PF_LABOR_CGE(ey) + q_i_pf(ey,"Households","Capital")*P_PF_CAPITAL_CGE(ey)+transf_g_h(ey)+psc_h(ey)*sum((s),(tx_rate_sc(ey,"Labor",s)-SC_ENV_SUBSIDY_RATE(ey)-tx_rate_sc(ey,"Labor",s)*SC_ENV_SUBSIDY_RATE(ey))*P_PF_LABOR_CGE(ey)*Q_PF_LABOR_CGE(ey,s))+transf_ext_h(ey)
*- sum(pollut, top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_P_Q_CGE(ey,g)/(initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)))*Q_H_D_CGE(ey,g)) )*pollutant_price(ey,pollut,"Households"))

***???***- sum(pollut, top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g))/sum(g_alias, (initial_Q_H_D_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias)))*Q_H_D_CGE(ey,g)))*pollutant_price(ey,pollut,"Households"))
* last one - sum(pollut, top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_P_Q_CGE(ey,g)/(initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)))*Q_H_D_CGE(ey,g)) )*pollutant_price(ey,pollut,"Households"))

- sum(pollut, sum(g, top_down_pollutant_content(ey,pollut,"Households")*( (initial_P_Q_CGE(ey,g))/ sum(g_alias, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)) ) ) * Q_H_D_CGE(ey,g) *pollutant_price(ey,pollut,"Households") ) )


*- sum(pollut, top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g))/sum(g_alias, (initial_Q_H_D_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias)))*Q_H_D_CGE(ey,g)))*pollutant_price(ey,pollut,"Households"))
;

eq_3_7_2(ey)..
S_TOTAL_H_CGE(ey)=e=s_propensity_h(ey)*Y_H_CGE(ey);

eq_2_4_8(ey,s)..
(Q_PF_LABOR_CGE(ey,s)**(1/elasticity_va(s)))*a_va_pf(ey,"Capital",s)*(1+tx_rate_sc(ey,"Labor",s))*(1-SC_ENV_SUBSIDY_RATE(ey))*P_PF_LABOR_CGE(ey)=e=(Q_PF_CAPITAL_CGE(ey,s)**(1/elasticity_va(s)))*a_va_pf(ey,"Labor",s)*P_PF_CAPITAL_CGE(ey);

eq_2_4_9(ey,s)..
Q_VA_CGE(ey,s)=e=alpha_va(ey,s)*[ ( (a_va_pf(ey,"Labor",s)*(Q_PF_LABOR_CGE(ey,s)**((elasticity_va(s)-1)/elasticity_va(s)))) + (a_va_pf(ey,"Capital",s)*(Q_PF_CAPITAL_CGE(ey,s)**((elasticity_va(s)-1)/elasticity_va(s)))) )** ( elasticity_va(s)/(elasticity_va(s)-1) ) ];

eq_2_4_10(ey,s)..
Q_VA_CGE(ey,s)*P_VA_CGE(ey,s)=e= (1+tx_rate_sc(ey,"Labor",s))*(1-SC_ENV_SUBSIDY_RATE(ey))*Q_PF_LABOR_CGE(ey,s)*P_PF_LABOR_CGE(ey) + Q_PF_CAPITAL_CGE(ey,s)*P_PF_CAPITAL_CGE(ey);

eq_2_4_15(ey,g,s)..
Q_II_CGE(ey,g,s)=e=c_ii_share(ey,g,s)*Q_S_CGE(ey,s);

eq_2_4_16(ey,s)..
Q_VA_CGE(ey,s)=e=c_va_share(ey,s)*Q_S_CGE(ey,s);

eq_2_4_17(ey,s)..
Q_S_CGE(ey,s)*P_S_CGE(ey,s)+sum(i,e_transf_i_s(ey,i,s))=e= Q_VA_CGE(ey,s)*P_VA_CGE(ey,s)
*+ sum(g, Q_II_CGE(ey,g,s)*(1+tx_rate(ey,s,"Product_tax"))*P_Q_CGE(ey,g))+ emission_rate(ey,s)*Q_S_CGE(ey,s)*co2_price(ey) + e_tx_sam(ey,"Production_Taxes",s);
+ sum(g, Q_II_CGE(ey,g,s)*(1+tx_rate(ey,s,"Product_tax"))*P_Q_CGE(ey,g))
+ e_tx_sam(ey,"Production_Taxes",s);

eq_3_3_8(ey,g)..
(Q_S_CGE(ey,g)**(1/elasticity_d(g)))*a_d_m(ey,g)*P_S_CGE(ey,g)=e=(Q_M_CGE(ey,g)**(1/elasticity_d(g)))*a_d_q(ey,g)*p_m_initial(ey,g);

eq_3_3_9(ey,g)..
Q_D_CGE(ey,g)=e=  alpha_d(ey,g)*[ ( a_d_q(ey,g)*(Q_S_CGE(ey,g)**((elasticity_d(g)-1)/elasticity_d(g))) +  a_d_m(ey,g)*(Q_M_CGE(ey,g)**((elasticity_d(g)-1)/elasticity_d(g))) )** ( elasticity_d(g)/(elasticity_d(g)-1) ) ];

eq_3_3_10(ey,g)..
Q_D_CGE(ey,g)*P_D_CGE(ey,g)=e=P_S_CGE(ey,g)*Q_S_CGE(ey,g) + p_m_initial(ey,g)*Q_M_CGE(ey,g) + sum(pollut, (top_down_pollutant_content(ey,pollut,g)/initial_Q_D_CGE(ey,g))*Q_D_CGE(ey,g)*pollutant_price(ey,pollut,g))   ;

eq_3_3_17(ey,g)..
Q_Q_CGE(ey,g)*(b_q_q(ey,g)**elasticity_q(g))*(((1+tx_rate(ey,"Exports","Product_Tax"))*p_ex_initial(ey,g))**elasticity_q(g))=e=Q_EX_CGE(ey,g)*(b_q_ex(ey,g)**elasticity_q(g))*(P_Q_CGE(ey,g)**elasticity_q(g));

eq_3_3_18(ey,g)..
Q_D_CGE(ey,g)=e= beta_q(ey,g)*[ ( b_q_q(ey,g)*(Q_Q_CGE(ey,g)**((elasticity_q(g)+1)/elasticity_q(g))) + b_q_ex(ey,g)*(Q_EX_CGE(ey,g)**((elasticity_q(g)+1)/elasticity_q(g))) )** ( elasticity_q(g)/(elasticity_q(g)+1) ) ];

eq_3_3_19(ey,g)..
Q_D_CGE(ey,g)*P_D_CGE(ey,g)=e= Q_Q_CGE(ey,g)*P_Q_CGE(ey,g) - RENEWABLE_PREMIUM_TAX_RATE(ey,g)*Q_Q_CGE(ey,g)*P_Q_CGE(ey,g) + (LUMP_SUM_ENV_SUBSIDY(ey))*Q_Q_CGE(ey,g)*P_Q_CGE(ey,g) + p_ex_initial(ey,g)*Q_EX_CGE(ey,g);
*Q_D_CGE(ey,g)*P_D_CGE(ey,g)=e= (1+RENEWABLE_PREMIUM_TAX_RATE(ey,g))*Q_Q_CGE(ey,g)*P_Q_CGE(ey,g) + LUMP_SUM_ENV_SUBSIDY(ey,g) + p_ex_initial(ey,g)*Q_EX_CGE(ey,g);

eq_3_4_1(ey)..
Y_G_CGE(ey)=e=q_i_pf(ey,"Government","Labor")*P_PF_LABOR_CGE(ey) + q_i_pf(ey,"Government","Capital")*P_PF_CAPITAL_CGE(ey)+transf_ext_g(ey)+Y_TAX_CGE(ey);

eq_3_4_2(ey)..
E_G_CGE(ey)=e=sum(g,(1+tx_rate(ey,"Government","Product_Tax"))*P_Q_CGE(ey,g)*q_gov_initial(ey,g))+transf_g_h(ey)+psc_h(ey)*sum((s),(tx_rate_sc(ey,"Labor",s)-SC_ENV_SUBSIDY_RATE(ey)-tx_rate_sc(ey,"Labor",s)*SC_ENV_SUBSIDY_RATE(ey))*P_PF_LABOR_CGE(ey)*Q_PF_LABOR_CGE(ey,s))+sum(s,e_transf_i_s(ey,"Government",s));

eq_3_4_3(ey)..
S_TOTAL_G_CGE(ey)=e=Y_G_CGE(ey)-E_G_CGE(ey);

eq_3_4_4(ey)..
Y_TAX_CGE(ey)=e=sum((s),(tx_rate_sc(ey,"Labor",s)-SC_ENV_SUBSIDY_RATE(ey)-tx_rate_sc(ey,"Labor",s)*SC_ENV_SUBSIDY_RATE(ey))*P_PF_LABOR_CGE(ey)*Q_PF_LABOR_CGE(ey,s)) +  sum(s,e_tx_sam(ey,"Production_Taxes",s)) + sum(s, sum(g, tx_rate(ey,s,"Product_tax")*P_Q_CGE(ey,g)*Q_II_CGE(ey,g,s)))

- sum(s,LUMP_SUM_ENV_SUBSIDY(ey)*Q_Q_CGE(ey,s)*P_Q_CGE(ey,s))

*+  sum(s$ets_s(s), emission_rate(ey,s)*Q_S_CGE(ey,s)*co2_price(ey)) + sum(g, tx_rate(ey,"Households","Product_Tax")*P_Q_CGE(ey,g)*Q_H_D_CGE(ey,g)) + sum(g,tx_rate(ey,"Government","Product_Tax")*P_Q_CGE(ey,g)*q_gov_initial(ey,g)) + sum(g,tx_rate(ey,"Saves-Investments","Product_Tax")*P_Q_CGE(ey,g)*Q_I_D_CGE(ey,g)) + sum(g,tx_rate(ey,"Exports","Product_Tax")*p_ex_initial(ey,g)*Q_EX_CGE(ey,g)) ;
*+  sum((s,pollut), top_down_pollutant_content(ey,pollut,s)*(initial_P_S_CGE(ey,s)/(initial_Q_S_CGE(ey,s)*initial_P_S_CGE(ey,s)))*Q_S_CGE(ey,s)*pollutant_price(ey,pollut,s))

+ sum((s,pollut), (top_down_pollutant_content(ey,pollut,s)/initial_Q_D_CGE(ey,s))*Q_D_CGE(ey,s)*pollutant_price(ey,pollut,s))

+ sum(g, tx_rate(ey,"Households","Product_Tax")*P_Q_CGE(ey,g)*Q_H_D_CGE(ey,g)) + sum(g,tx_rate(ey,"Government","Product_Tax")*P_Q_CGE(ey,g)*q_gov_initial(ey,g)) + sum(g,tx_rate(ey,"Saves-Investments","Product_Tax")*P_Q_CGE(ey,g)*Q_I_D_CGE(ey,g)) + sum(g,tx_rate(ey,"Exports","Product_Tax")*p_ex_initial(ey,g)*Q_EX_CGE(ey,g))
*+ sum(pollut, top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_P_Q_CGE(ey,g)/(initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)))*Q_H_D_CGE(ey,g)) )*pollutant_price(ey,pollut,"Households"))

***???***+ sum(pollut, top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g))/sum(g_alias, (initial_Q_H_D_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias)))*Q_H_D_CGE(ey,g)))*pollutant_price(ey,pollut,"Households"))
* last one + sum(pollut, top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_P_Q_CGE(ey,g)/(initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)))*Q_H_D_CGE(ey,g)) )*pollutant_price(ey,pollut,"Households"))

+ sum(pollut, sum(g, top_down_pollutant_content(ey,pollut,"Households")*( (initial_P_Q_CGE(ey,g))/ sum(g_alias, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)) ) ) * Q_H_D_CGE(ey,g) *pollutant_price(ey,pollut,"Households") ) )


+ sum(g,RENEWABLE_PREMIUM_TAX_RATE(ey,g)*Q_Q_CGE(ey,g)*P_Q_CGE(ey,g))
;

eq_3_5_1(ey)..
S_TOTAL_CGE(ey)=e=S_TOTAL_H_CGE(ey)+S_TOTAL_G_CGE(ey)+S_TOTAL_EXT_CGE(ey)+transf_ext_k(ey);

eq_3_5_2(ey)..
S_TOTAL_EXT_CGE(ey)=e=sum(g,p_m_initial(ey,g)*Q_M_CGE(ey,g))-sum(g,(1+tx_rate(ey,"Exports","Product_tax"))*p_ex_initial(ey,g)*Q_EX_CGE(ey,g))-transf_ext_g(ey)-transf_ext_h(ey)-transf_ext_k(ey);

eq_3_5_3(ey,g)..
Theta(ey,g)*I_TOTAL_CGE(ey)=e=Q_I_D_CGE(ey,g)*((1+tx_rate(ey,"Saves-Investments","Product_Tax"))*P_Q_CGE(ey,g));

eq_3_6_1_a(ey)..
sum(s, Q_PF_LABOR_CGE(ey,s))=e=sum(i,q_i_pf(ey,i,"Labor"));

eq_3_6_1_b(ey)..
sum(s, Q_PF_CAPITAL_CGE(ey,s))=e=sum(i,q_i_pf(ey,i,"Capital"));

eq_3_6_2(ey,g)..
Q_Q_CGE(ey,g)=e=Q_H_D_CGE(ey,g)+q_gov_initial(ey,g)+sum(s,Q_II_CGE(ey,g,s))+Q_I_D_CGE(ey,g);

eq_3_6_3(ey)..
I_TOTAL_CGE(ey)=e=S_TOTAL_CGE(ey) + WALRAS_CGE(ey);

*---------Consumer price Index-------------------------
eq_CPI(ey)..
         CPI_CGE(ey) =e= sum(g, P_Q_CGE(ey,g)*mu_cpi(ey,g));

*-------Objective function for NLP resolution----------
eq_object_function_CGE..
         DUMMY_CGE =e= 1;


*-------Environmental Tax Reform----------
eq_extra_1(ey,pollut)..
*Y_ENV_TAX(ey) =e= ( sum(pollut$(not sameas(pollut,"CO2e")), top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_P_Q_CGE(ey,g)/(initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)))*Q_H_D_CGE(ey,g)) )*pollutant_price(ey,pollut,"Households"))  + sum((s,pollut)$( not ( sameas(pollut,"CO2e") and ETS_s(s) ) ), top_down_pollutant_content(ey,pollut,s)*(initial_P_S_CGE(ey,s)/(initial_Q_S_CGE(ey,s)*initial_P_S_CGE(ey,s)))*Q_S_CGE(ey,s)*pollutant_price(ey,pollut,s)) )$(exec_social_contributions_enviromental_tax_reform or exec_lump_sum_enviromental_tax_reform);
*Y_ENV_TAX(ey) =e= ( sum(pollut$(not sameas(pollut,"CO2e")), top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g))/sum(g_alias, (initial_Q_H_D_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias)))*Q_H_D_CGE(ey,g)))*pollutant_price(ey,pollut,"Households"))  + sum((s,pollut)$( not ( sameas(pollut,"CO2e") and ETS_s(s) ) ), top_down_pollutant_content(ey,pollut,s)*(initial_P_S_CGE(ey,s)/(initial_Q_S_CGE(ey,s)*initial_P_S_CGE(ey,s)))*Q_S_CGE(ey,s)*pollutant_price(ey,pollut,s)) )$(exec_social_contributions_enviromental_tax_reform or exec_lump_sum_enviromental_tax_reform);

*Y_ENV_TAX(ey) =e= ( sum(pollut$(not sameas(pollut,"CO2e")), top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g))/sum(g_alias, (initial_Q_H_D_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias)))*Q_H_D_CGE(ey,g)))*pollutant_price(ey,pollut,"Households"))  + sum((s,pollut)$( not ( sameas(pollut,"CO2e") and ETS_s(s) ) ), top_down_pollutant_content(ey,pollut,s)*(initial_P_S_CGE(ey,s)/(initial_Q_S_CGE(ey,s)*initial_P_S_CGE(ey,s)))*Q_S_CGE(ey,s)*pollutant_price(ey,pollut,s)) )$(exec_social_contributions_enviromental_tax_reform or exec_lump_sum_enviromental_tax_reform);
Y_ENV_TAX(ey,pollut) =e=
* last one top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g))/sum(g_alias, (initial_Q_H_D_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias)))*Q_H_D_CGE(ey,g)))*pollutant_price(ey,pollut,"Households")

sum(g, top_down_pollutant_content(ey,pollut,"Households")*( (initial_P_Q_CGE(ey,g))/ sum(g_alias, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)) ) ) * Q_H_D_CGE(ey,g) *pollutant_price(ey,pollut,"Households") )
+ sum(s$( not ( sameas(pollut,"CO2e_ETS") and ETS_s(s) ) ), (top_down_pollutant_content(ey,pollut,s)/initial_Q_D_CGE(ey,s))*Q_D_CGE(ey,s)*pollutant_price(ey,pollut,s));


***???****top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g))/sum(g_alias, (initial_Q_H_D_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias)))*Q_H_D_CGE(ey,g)))*pollutant_price(ey,pollut,"Households")
*( sum(pollut$(not sameas(pollut,"CO2e")), top_down_pollutant_content(ey,pollut,"Households")*( sum(g, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g))/sum(g_alias, (initial_Q_H_D_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias)))*Q_H_D_CGE(ey,g)))*pollutant_price(ey,pollut,"Households"))  + sum((s,pollut)$( not ( sameas(pollut,"CO2e") and ETS_s(s) ) ), (top_down_pollutant_content(ey,pollut,s)/initial_Q_S_CGE(ey,s))*Q_S_CGE(ey,s)*pollutant_price(ey,pollut,s)) )$(exec_social_contributions_enviromental_tax_reform or exec_lump_sum_enviromental_tax_reform);



eq_extra_2(ey)..
SC_ENV_SUBSIDY_RATE(ey) =e= ( sum(pollut, Y_ENV_TAX(ey,pollut)) / sum(s_alias,( (1+tx_rate_sc(ey,"Labor",s_alias))*Q_PF_LABOR_CGE(ey,s_alias)*P_PF_LABOR_CGE(ey) ) ) )$(exec_social_contributions_enviromental_tax_reform);
*SC_ENV_SUBSIDY_RATE(ey) =e= ( Y_ENV_TAX(ey)                    / sum(s, (1+tx_rate_sc(ey,"Labor",s))*Q_PF_LABOR_CGE(ey,s)*P_PF_LABOR_CGE(ey) ) )$(exec_social_contributions_enviromental_tax_reform);


eq_extra_3(ey)..
LUMP_SUM_ENV_SUBSIDY(ey) =e= ( sum(pollut, Y_ENV_TAX(ey,pollut)) / sum(s_alias, Q_Q_CGE(ey,s_alias)*P_Q_CGE(ey,s_alias) ) )$(exec_lump_sum_enviromental_tax_reform);
*LUMP_SUM_ENV_SUBSIDY(ey,s) =e= ( Y_ENV_TAX(ey)*( initial_Q_Q_CGE(ey,s)*initial_P_Q_CGE(ey,s) / sum(s_alias, initial_Q_Q_CGE(ey,s_alias)*initial_P_Q_CGE(ey,s_alias) ) ) )$(exec_lump_sum_enviromental_tax_reform);

eq_extra_4(ey,s)..
RENEWABLE_PREMIUM_TAX_RATE(ey,s) =e= ( renewable_premium_payments_tax(ey) /sum(g_alias$renewable_premium_tax_sectors(g_alias),(Q_Q_CGE(ey,g_alias)*P_Q_CGE(ey,g_alias))))$(exec_renew_premium_tax_reform and renewable_premium_tax_sectors(s));


*RENEWABLE_PREMIUM_TAX_RATE(ey,g) =e= ( renewable_premium_payments(ey)*( initial_Q_Q_CGE(ey,g)*initial_P_Q_CGE(ey,g) / sum(g_alias, initial_Q_Q_CGE(ey,g_alias)*initial_P_Q_CGE(ey,g_alias) ) )/(Q_Q_CGE(ey,g)*P_Q_CGE(ey,g)))$(exec_renew_premium_tax_reform);


*-------------------------------------------------------------------------------
*-------------------------------- Defining CGE Model ---------------------------
*-------------------------------------------------------------------------------

* initializing variables ---------------------------------------------
Q_H_D_CGE.l(ey,g)=initial_Q_H_D_CGE(ey,g);
P_PF_LABOR_CGE.l(ey)=initial_P_PF_CGE(ey,"Labor");
P_PF_CAPITAL_CGE.l(ey)=initial_P_PF_CGE(ey,"Capital");
Y_H_CGE.l(ey)=initial_Y_H_CGE(ey);
Q_PF_LABOR_CGE.l(ey,s)=initial_Q_PF_CGE(ey,"Labor",s);
Q_PF_CAPITAL_CGE.l(ey,s)=initial_Q_PF_CGE(ey,"Capital",s);
Q_VA_CGE.l(ey,s)=initial_Q_VA_CGE(ey,s);
P_VA_CGE.l(ey,s)=initial_P_VA_CGE(ey,s);
Q_II_CGE.l(ey,g,s)=initial_Q_II_CGE(ey,g,s);
Q_S_CGE.l(ey,s)=initial_Q_S_CGE(ey,s);
P_S_CGE.l(ey,g)=initial_P_S_CGE(ey,g);
Q_M_CGE.l(ey,g)=initial_Q_M_CGE(ey,g);
Q_D_CGE.l(ey,g)=initial_Q_D_CGE(ey,g);
P_D_CGE.l(ey,g)=initial_P_D_CGE(ey,g);
Q_EX_CGE.l(ey,g)=initial_Q_EX_CGE(ey,g);
Q_Q_CGE.l(ey,g)=initial_Q_Q_CGE(ey,g);
P_Q_CGE.l(ey,g)=initial_P_Q_CGE(ey,g);
Y_G_CGE.l(ey)=initial_Y_G_CGE(ey);
E_G_CGE.l(ey)=initial_E_G_CGE(ey);
Y_TAX_CGE.l(ey)=initial_Y_TAX_CGE(ey);
S_TOTAL_CGE.l(ey)=initial_S_TOTAL_CGE(ey);
S_TOTAL_H_CGE.l(ey)=initial_S_TOTAL_H_CGE(ey);
S_TOTAL_G_CGE.l(ey)=initial_S_TOTAL_G_CGE(ey);
S_TOTAL_EXT_CGE.l(ey)=initial_S_TOTAL_EXT_CGE(ey);
I_TOTAL_CGE.l(ey)=initial_I_TOTAL_CGE(ey);
Q_I_D_CGE.l(ey,g)=initial_Q_I_D_CGE(ey,g);
CPI_CGE.l(ey)=initial_CPI(ey);
DUMMY_CGE.l=1;

Y_ENV_TAX.l(ey,pollut) = sum(g, top_down_pollutant_content(ey,pollut,"Households")*( (initial_P_Q_CGE(ey,g))/ sum(g_alias, (initial_Q_H_D_CGE(ey,g)*initial_P_Q_CGE(ey,g)) ) ) * Q_H_D_CGE.l(ey,g) *pollutant_price(ey,pollut,"Households") ) + sum(s$( not ( sameas(pollut,"CO2e_ETS") and ETS_s(s) ) ), (top_down_pollutant_content(ey,pollut,s)/initial_Q_D_CGE(ey,s))*Q_D_CGE.l(ey,s)*pollutant_price(ey,pollut,s));
SC_ENV_SUBSIDY_RATE.l(ey) = ( sum(pollut, Y_ENV_TAX.l(ey,pollut)) / sum(s_alias,( (1+tx_rate_sc(ey,"Labor",s_alias))*Q_PF_LABOR_CGE.l(ey,s_alias)*P_PF_LABOR_CGE.l(ey) ) ) )$(exec_social_contributions_enviromental_tax_reform);
LUMP_SUM_ENV_SUBSIDY.l(ey) = ( sum(pollut, Y_ENV_TAX.l(ey,pollut)) / sum(s_alias, Q_Q_CGE.l(ey,s_alias)*P_Q_CGE.l(ey,s_alias) ) )$(exec_lump_sum_enviromental_tax_reform);
*RENEWABLE_PREMIUM_TAX_RATE.l(ey,s) = ( renewable_premium_payments_tax(ey) /sum(g_alias$renewable_premium_tax_sectors(g_alias),(Q_Q_CGE.l(ey,g_alias)*P_Q_CGE.l(ey,g_alias))))$(exec_renew_premium_tax_reform and renewable_premium_tax_sectors(s));

*( renewable_premium_payments(ey)/sum(g_alias,(Q_Q_CGE.l(ey,g_alias)*P_Q_CGE.l(ey,g_alias))))$(exec_renew_premium_tax_reform);


* Setting lower bounds to avoid vcPower: GRAD SINGULAR: x**c, x=0, 0<c<1 ---------
parameter lower_bound /1e-15/;
Q_H_D_CGE.lo(ey,g)$(Q_H_D_CGE.l(ey,g)>lower_bound)=lower_bound;
P_PF_LABOR_CGE.lo(ey)$(P_PF_LABOR_CGE.l(ey)>lower_bound)=lower_bound;
P_PF_CAPITAL_CGE.lo(ey)$(P_PF_CAPITAL_CGE.l(ey)>lower_bound)=lower_bound;
Y_H_CGE.lo(ey)$(Y_H_CGE.l(ey)>lower_bound)=lower_bound;
Q_PF_LABOR_CGE.lo(ey,s)$(Q_PF_LABOR_CGE.l(ey,s)>lower_bound)=lower_bound;
Q_PF_CAPITAL_CGE.lo(ey,s)$(Q_PF_CAPITAL_CGE.l(ey,s)>lower_bound)=lower_bound;
Q_VA_CGE.lo(ey,s)$(Q_VA_CGE.l(ey,s)>lower_bound)=lower_bound;
P_VA_CGE.lo(ey,s)$(P_VA_CGE.l(ey,s)>lower_bound)=lower_bound;
Q_II_CGE.lo(ey,g,s)$(Q_II_CGE.l(ey,g,s)>lower_bound)=lower_bound;
Q_S_CGE.lo(ey,s)$(Q_S_CGE.l(ey,s)>lower_bound)=lower_bound;
P_S_CGE.lo(ey,g)$(P_S_CGE.l(ey,g)>lower_bound)=lower_bound;
Q_M_CGE.lo(ey,g)$(Q_M_CGE.l(ey,g)>lower_bound)=lower_bound;
Q_D_CGE.lo(ey,g)$(Q_D_CGE.l(ey,g)>lower_bound)=lower_bound;
P_D_CGE.lo(ey,g)$(P_D_CGE.l(ey,g)>lower_bound)=lower_bound;
Q_EX_CGE.lo(ey,g)$(Q_EX_CGE.l(ey,g)>lower_bound)=lower_bound;
Q_Q_CGE.lo(ey,g)$(Q_Q_CGE.l(ey,g)>lower_bound)=lower_bound;
P_Q_CGE.lo(ey,g)$(P_Q_CGE.l(ey,g)>lower_bound)=lower_bound;
Y_G_CGE.lo(ey)$(Y_G_CGE.l(ey)>lower_bound)=lower_bound;
E_G_CGE.lo(ey)$(E_G_CGE.l(ey)>lower_bound)=lower_bound;
Y_TAX_CGE.lo(ey)$(Y_TAX_CGE.l(ey)>lower_bound)=lower_bound;
S_TOTAL_CGE.lo(ey)$(S_TOTAL_CGE.l(ey)>lower_bound)=lower_bound;
S_TOTAL_H_CGE.lo(ey)$(S_TOTAL_H_CGE.l(ey)>lower_bound)=lower_bound;
S_TOTAL_G_CGE.lo(ey)$(S_TOTAL_G_CGE.l(ey)>lower_bound)=lower_bound;
S_TOTAL_EXT_CGE.lo(ey)$(S_TOTAL_EXT_CGE.l(ey)>lower_bound)=lower_bound;
I_TOTAL_CGE.lo(ey)$(I_TOTAL_CGE.l(ey)>lower_bound)=lower_bound;
Q_I_D_CGE.lo(ey,g)$(Q_I_D_CGE.l(ey,g)>lower_bound)=lower_bound;


* Fixing variables with initial value zero ------
Q_H_D_CGE.fx(ey,g)$(initial_Q_H_D_CGE(ey,g)=0)=0;
P_PF_LABOR_CGE.fx(ey)$(initial_P_PF_CGE(ey,"Labor")=0)=0;
P_PF_CAPITAL_CGE.fx(ey)$(initial_P_PF_CGE(ey,"Capital")=0)=0;
Y_H_CGE.fx(ey)$(initial_Y_H_CGE(ey)=0)=0;
Q_PF_LABOR_CGE.fx(ey,s)$(initial_Q_PF_CGE(ey,"Labor",s)=0)=0;
Q_PF_CAPITAL_CGE.fx(ey,s)$(initial_Q_PF_CGE(ey,"Capital",s)=0)=0;
Q_VA_CGE.fx(ey,s)$(initial_Q_VA_CGE(ey,s)=0)=0;
P_VA_CGE.fx(ey,s)$(initial_P_VA_CGE(ey,s)=0)=0;
Q_II_CGE.fx(ey,g,s)$(initial_Q_II_CGE(ey,g,s)=0)=0;
Q_S_CGE.fx(ey,s)$(initial_Q_S_CGE(ey,s)=0)=0;
P_S_CGE.fx(ey,g)$(initial_P_S_CGE(ey,g)=0)=0;
Q_M_CGE.fx(ey,g)$(initial_Q_M_CGE(ey,g)=0)=0;
Q_D_CGE.fx(ey,g)$(initial_Q_D_CGE(ey,g)=0)=0;
P_D_CGE.fx(ey,g)$(initial_P_D_CGE(ey,g)=0)=0;
Q_EX_CGE.fx(ey,g)$(initial_Q_EX_CGE(ey,g)=0)=0;
Q_Q_CGE.fx(ey,g)$(initial_Q_Q_CGE(ey,g)=0)=0;
P_Q_CGE.fx(ey,g)$(initial_P_Q_CGE(ey,g)=0)=0;
Y_G_CGE.fx(ey)$(initial_Y_G_CGE(ey)=0)=0;
E_G_CGE.fx(ey)$(initial_E_G_CGE(ey)=0)=0;
Y_TAX_CGE.fx(ey)$(initial_Y_TAX_CGE(ey)=0)=0;
S_TOTAL_CGE.fx(ey)$(initial_S_TOTAL_CGE(ey)=0)=0;
S_TOTAL_H_CGE.fx(ey)$(initial_S_TOTAL_H_CGE(ey)=0)=0;
S_TOTAL_G_CGE.fx(ey)$(initial_S_TOTAL_G_CGE(ey)=0)=0;
S_TOTAL_EXT_CGE.fx(ey)$(initial_S_TOTAL_EXT_CGE(ey)=0)=0;
I_TOTAL_CGE.fx(ey)$(initial_I_TOTAL_CGE(ey)=0)=0;
Q_I_D_CGE.fx(ey,g)$(initial_Q_I_D_CGE(ey,g)=0)=0;
CPI_CGE.fx(ey)$(initial_CPI(ey)=0)=0;



display
Q_H_D_CGE.l, P_PF_LABOR_CGE.l, P_PF_CAPITAL_CGE.l, Y_H_CGE.l, Q_PF_LABOR_CGE.l,
Q_PF_CAPITAL_CGE.l, Q_VA_CGE.l, P_VA_CGE.l, Q_II_CGE.l, Q_S_CGE.l ,P_S_CGE.l,
Q_M_CGE.l, P_D_CGE.l, Q_EX_CGE.l, Q_Q_CGE.l, P_Q_CGE.l, Y_G_CGE.l, E_G_CGE.l,
Y_TAX_CGE.l, S_TOTAL_CGE.l, S_TOTAL_H_CGE.l, S_TOTAL_G_CGE.l, S_TOTAL_EXT_CGE.l,
I_TOTAL_CGE.l, Q_I_D_CGE.l, CPI_CGE.l;

* numeraire ---------------------------------------------
CPI_CGE.fx(ey)=initial_CPI(ey);

* NLP Model -------------------------------------------------
Model CGE_NLP   /
                 eq_2_3_8, eq_3_7_1, eq_3_7_2, eq_2_4_8, eq_2_4_9, eq_2_4_10,
                 eq_2_4_15, eq_2_4_16, eq_2_4_17, eq_3_3_8, eq_3_3_9, eq_3_3_10,
                 eq_3_3_17, eq_3_3_18, eq_3_3_19, eq_3_4_1, eq_3_4_2, eq_3_4_3, eq_3_4_4,
                 eq_3_5_1, eq_3_5_2, eq_3_5_3, eq_3_6_1_a, eq_3_6_1_b, eq_3_6_2,
                 eq_3_6_3, eq_CPI, eq_object_function_CGE
                 eq_extra_1, eq_extra_2, eq_extra_3, eq_extra_4
                /;

* MCP Model -------------------------------------------------
Model CGE_MCP   /
                 eq_2_3_8.Q_H_D_CGE, eq_3_7_1.Y_H_CGE, eq_3_7_2.S_TOTAL_H_CGE,
                 eq_2_4_8.Q_PF_LABOR_CGE, eq_2_4_9.Q_PF_CAPITAL_CGE,
                 eq_2_4_10.Q_VA_CGE, eq_2_4_15.Q_II_CGE, eq_2_4_16.P_VA_CGE,
                 eq_2_4_17.Q_S_CGE, eq_3_3_8.Q_M_CGE, eq_3_3_9.P_S_CGE,
                 eq_3_3_10.Q_D_CGE, eq_3_3_17.Q_EX_CGE,  eq_3_3_18.P_D_CGE,
                 eq_3_3_19.Q_Q_CGE, eq_3_4_1.Y_G_CGE, eq_3_4_2.E_G_CGE,
                 eq_3_4_3.S_TOTAL_G_CGE, eq_3_4_4.Y_TAX_CGE, eq_3_5_1.S_TOTAL_CGE,
                 eq_3_5_2.S_TOTAL_EXT_CGE, eq_3_5_3.Q_I_D_CGE,
                 eq_3_6_1_a.P_PF_LABOR_CGE, eq_3_6_1_b.P_PF_CAPITAL_CGE,
                 eq_3_6_2.P_Q_CGE, eq_3_6_3.I_TOTAL_CGE, eq_CPI.CPI_CGE
                 eq_extra_1.Y_ENV_TAX, eq_extra_2.SC_ENV_SUBSIDY_RATE, eq_extra_3.LUMP_SUM_ENV_SUBSIDY ,eq_extra_4.RENEWABLE_PREMIUM_TAX_RATE
                /;

*-------------------------------------------------------------------------------

WALRAS_CGE.fx(ey)=0;
CGE_NLP.HOLDFIXED= 1;
CGE_MCP.HOLDFIXED= 1;
*OPTION ITERLIM = 0;
option limcol = 1000;
option limrow = 1000;
option nlp=conopt;
option mcp=path;



