$Title Sets Definition
$ontext
--------------------------------------------------------------------------------
------------------------------ General Header ----------------------------------
--------------------------------------------------------------------------------
         Hybrid Top-down Computable General Equilibrium and Bottom-up Electricity Expansion Model
         Renato Rodrigues
         Instituto de Investigacin Tecnolgica
         Date: 26, may, 2011
--------------------------------------------------------------------------------
--------------------------- End of General Header ------------------------------
--------------------------------------------------------------------------------
$offtext

*-------------------------------------------------------------------------------
*------------------------------- Defining Options ------------------------------
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
*------------------------------ Solver definition ------------------------------
*-------------------------------------------------------------------------------
option LP=CPLEX;
option NLP=CONOPT;
option MCP=PATH;

*-------------------------------------------------------------------------------
*------------------------ Choose the years to be simulated ---------------------
*-------------------------------------------------------------------------------
*Defining years of execution
sets
        y        years           / 1900*2100 /
    ey(y)        execution year  (for CGE model)                                         /2005/
    eys(y)       execution years (for electricity model)                                 /2005*2005/;

*-------------------------------------------------------------------------------
*---------- Choose the costs to be considered in the electricity model ---------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF
Scalars
       exec_fc           Fuel costs                                                      /1/
       exec_co2          CO2 emission costs                                              /1/
*preciso revisar desagregacao porque no esto saindo valores aceitaveis quando considero co2

       exec_vom          Operation and maintenance variable equipaments reposition costs /1/
       exec_oem_equip    Operation and maintenance equipments fixed costs                /1/
       exec_oem_labor    Operation and maintenance labor fixed costs                     /1/
       exec_oem_sc       Operation and maintenance social contribution fixed costs       /1/
       exec_capac        Installed capacity amortization costs paid in the year          /1/
       exec_emiss_rights Technology emission rights distributed by the government        /1/
       exec_renew_prem   Renewable premium income                                        /0/;


*-------------------------------------------------------------------------------
*------------------------ Choose the location to be considered in the models ---------------------
*-------------------------------------------------------------------------------
*Defining locations of execution (I am having problems with extra peninsular location due to the high level of non-paid capacity; therefore its execution should be maintained null for the time being)
Set      l               Peninsular only electricity market                              /Peninsular/;
*set      l               Peninsular and Extra Peninsular electricity markets             /Peninsular, Extra Peninsular/;

alias (l,l_alias);

*-------------------------------------------------------------------------------
*---------------------- Choose the DR policy to be evaluated -------------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF
Scalars
*Active Demand Management policy
       exec_DR_displac Demand reponse with load displacements                            /0/
       exec_DR_reduc   Demand reponse with load conservation savings                     /0/;

*-------------------------------------------------------------------------------
*------- Choose the objective fucnction of the SAM disaggregation scheme -------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF  (choose only one of the bellow alternatives)
Scalars
       exec_MinMax       MinMax deviation                                                /0/
       exec_MinMax_plus_lineal_term MinMax with additional term to exclude unnecessary deviations /1/
       exec_Quadratic   Min the squared deviation                                        /0/;

*-------------------------------------------------------------------------------
*----------------- Choose the Top-Down model type - MCP or NLP -----------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF (choose only one of the bellow alternatives)
Scalars
       exec_MCP          Top-Down model soved as a mixed complementarity problem         /1/
       exec_NLP          Top-Down model solved as a non lineal problem                   /0/;


*-------------------------------------------------------------------------------
*------------------- Choose the Bottom-Up model type - MCP or LP ----------------------
*-------------------------------------------------------------------------------
* 1 = ON / 0 = OFF (choose only one of the bellow alternatives)
Scalars
       exec_BU_MCP       Bottom-Up model soved as a mixed complementarity problem        /0/
       exec_BU_LP        Bottom-Up model solved as a lineal problem                      /1/;


*-------------------------------------------------------------------------------
*-------------------------- Load segments aggregation --------------------------
*-------------------------------------------------------------------------------
sets
month / january,february,march,april,may,june,july,august,september,october,november,december /
day / 1*31 /
hour / 1*25 /
daytype / Working,Holiday /
weekday / Monday,Tuesday,Wednesday,Thursday,Friday,Saturday,Sunday /
p period load segment / Winter_Monday,Winter_Tuesday,Winter_Wednesday,Winter_Thursday,Winter_Friday,Winter_Holidays,Summer_Monday,Summer_Tuesday,Summer_Wednesday,Summer_Thursday,Summer_Friday,Summer_Holidays /
load_segment_definition(p,month,daytype,weekday) / Winter_Monday.january.Working.Monday,Winter_Tuesday.january.Working.Tuesday,Winter_Wednesday.january.Working.Wednesday,Winter_Thursday.january.Working.Thursday,Winter_Friday.january.Working.Friday,Winter_Holidays.january.Holiday.Friday,Winter_Holidays.january.Holiday.Monday,Winter_Holidays.january.Holiday.Saturday,Winter_Holidays.january.Holiday.Sunday,Winter_Holidays.january.Holiday.Thursday,Winter_Holidays.january.Holiday.Tuesday,Winter_Holidays.january.Holiday.Wednesday,Winter_Monday.february.Working.Monday,Winter_Tuesday.february.Working.Tuesday,Winter_Wednesday.february.Working.Wednesday,Winter_Thursday.february.Working.Thursday,Winter_Friday.february.Working.Friday,Winter_Holidays.february.Holiday.Friday,Winter_Holidays.february.Holiday.Monday,Winter_Holidays.february.Holiday.Saturday,Winter_Holidays.february.Holiday.Sunday,Winter_Holidays.february.Holiday.Thursday,Winter_Holidays.february.Holiday.Tuesday,Winter_Holidays.february.Holiday.Wednesday,Winter_Monday.march.Working.Monday,Winter_Tuesday.march.Working.Tuesday,Winter_Wednesday.march.Working.Wednesday,Winter_Thursday.march.Working.Thursday,Winter_Friday.march.Working.Friday,Winter_Holidays.march.Holiday.Friday,Winter_Holidays.march.Holiday.Monday,Winter_Holidays.march.Holiday.Saturday,Winter_Holidays.march.Holiday.Sunday,Winter_Holidays.march.Holiday.Thursday,Winter_Holidays.march.Holiday.Tuesday,Winter_Holidays.march.Holiday.Wednesday,Winter_Monday.october.Working.Monday,Winter_Tuesday.october.Working.Tuesday,Winter_Wednesday.october.Working.Wednesday,Winter_Thursday.october.Working.Thursday,Winter_Friday.october.Working.Friday,Winter_Holidays.october.Holiday.Friday,Winter_Holidays.october.Holiday.Monday,Winter_Holidays.october.Holiday.Saturday,Winter_Holidays.october.Holiday.Sunday,Winter_Holidays.october.Holiday.Thursday,Winter_Holidays.october.Holiday.Tuesday,Winter_Holidays.october.Holiday.Wednesday,Winter_Monday.november.Working.Monday,Winter_Tuesday.november.Working.Tuesday,Winter_Wednesday.november.Working.Wednesday,Winter_Thursday.november.Working.Thursday,Winter_Friday.november.Working.Friday,Winter_Holidays.november.Holiday.Friday,Winter_Holidays.november.Holiday.Monday,Winter_Holidays.november.Holiday.Saturday,Winter_Holidays.november.Holiday.Sunday,Winter_Holidays.november.Holiday.Thursday,Winter_Holidays.november.Holiday.Tuesday,Winter_Holidays.november.Holiday.Wednesday,Winter_Monday.december.Working.Monday,Winter_Tuesday.december.Working.Tuesday,Winter_Wednesday.december.Working.Wednesday,Winter_Thursday.december.Working.Thursday,Winter_Friday.december.Working.Friday,Winter_Holidays.december.Holiday.Friday,Winter_Holidays.december.Holiday.Monday,Winter_Holidays.december.Holiday.Saturday,Winter_Holidays.december.Holiday.Sunday,Winter_Holidays.december.Holiday.Thursday,Winter_Holidays.december.Holiday.Tuesday,Winter_Holidays.december.Holiday.Wednesday,Summer_Monday.april.Working.Monday,Summer_Tuesday.april.Working.Tuesday,Summer_Wednesday.april.Working.Wednesday,Summer_Thursday.april.Working.Thursday,Summer_Friday.april.Working.Friday,Summer_Holidays.april.Holiday.Friday,Summer_Holidays.april.Holiday.Monday,Summer_Holidays.april.Holiday.Saturday,Summer_Holidays.april.Holiday.Sunday,Summer_Holidays.april.Holiday.Thursday,Summer_Holidays.april.Holiday.Tuesday,Summer_Holidays.april.Holiday.Wednesday,Summer_Monday.may.Working.Monday,Summer_Tuesday.may.Working.Tuesday,Summer_Wednesday.may.Working.Wednesday,Summer_Thursday.may.Working.Thursday,Summer_Friday.may.Working.Friday,Summer_Holidays.may.Holiday.Friday,Summer_Holidays.may.Holiday.Monday,Summer_Holidays.may.Holiday.Saturday,Summer_Holidays.may.Holiday.Sunday,Summer_Holidays.may.Holiday.Thursday,Summer_Holidays.may.Holiday.Tuesday,Summer_Holidays.may.Holiday.Wednesday,Summer_Monday.june.Working.Monday,Summer_Tuesday.june.Working.Tuesday,Summer_Wednesday.june.Working.Wednesday,Summer_Thursday.june.Working.Thursday,Summer_Friday.june.Working.Friday,Summer_Holidays.june.Holiday.Friday,Summer_Holidays.june.Holiday.Monday,Summer_Holidays.june.Holiday.Saturday,Summer_Holidays.june.Holiday.Sunday,Summer_Holidays.june.Holiday.Thursday,Summer_Holidays.june.Holiday.Tuesday,Summer_Holidays.june.Holiday.Wednesday,Summer_Monday.july.Working.Monday,Summer_Tuesday.july.Working.Tuesday,Summer_Wednesday.july.Working.Wednesday,Summer_Thursday.july.Working.Thursday,Summer_Friday.july.Working.Friday,Summer_Holidays.july.Holiday.Friday,Summer_Holidays.july.Holiday.Monday,Summer_Holidays.july.Holiday.Saturday,Summer_Holidays.july.Holiday.Sunday,Summer_Holidays.july.Holiday.Thursday,Summer_Holidays.july.Holiday.Tuesday,Summer_Holidays.july.Holiday.Wednesday,Summer_Monday.august.Working.Monday,Summer_Tuesday.august.Working.Tuesday,Summer_Wednesday.august.Working.Wednesday,Summer_Thursday.august.Working.Thursday,Summer_Friday.august.Working.Friday,Summer_Holidays.august.Holiday.Friday,Summer_Holidays.august.Holiday.Monday,Summer_Holidays.august.Holiday.Saturday,Summer_Holidays.august.Holiday.Sunday,Summer_Holidays.august.Holiday.Thursday,Summer_Holidays.august.Holiday.Tuesday,Summer_Holidays.august.Holiday.Wednesday,Summer_Monday.september.Working.Monday,Summer_Tuesday.september.Working.Tuesday,Summer_Wednesday.september.Working.Wednesday,Summer_Thursday.september.Working.Thursday,Summer_Friday.september.Working.Friday,Summer_Holidays.september.Holiday.Friday,Summer_Holidays.september.Holiday.Monday,Summer_Holidays.september.Holiday.Saturday,Summer_Holidays.september.Holiday.Sunday,Summer_Holidays.september.Holiday.Thursday,Summer_Holidays.september.Holiday.Tuesday,Summer_Holidays.september.Holiday.Wednesday /;

Scalar
       UseLoadBlockAggregation                                                           /1/;
Set b load blocks /SuperOffPeak,OffPeak1,OffPeak2,Medium1,Medium2,Medium3,Medium4,Peak1,Peak2,SuperPeak/;

Parameters
Block_min_percentil(b) /Medium1 30,Medium2 40,Medium3 50,Medium4 60,OffPeak1 10,OffPeak2 20,Peak1 70,Peak2 80,SuperOffPeak 0,SuperPeak 90/
Block_max_percentil(b) /Medium1 40,Medium2 50,Medium3 60,Medium4 70,OffPeak1 20,OffPeak2 30,Peak1 80,Peak2 90,SuperOffPeak 10,SuperPeak 100/;

***********************************************************************************************************************************************************
